@@ -9,15 +9,18 @@ XML_TEMPLATE = (
 )
 
 
-def connect_mobile(ctx: huaweisms.api.common.ApiCtx):
+def connect_mobile(ctx):
+    # type: (huaweisms.api.common.ApiCtx) -> ...
     return switch_mobile_on(ctx)
 
 
-def disconnect_mobile(ctx: huaweisms.api.common.ApiCtx):
+def disconnect_mobile(ctx):
+    # type: (huaweisms.api.common.ApiCtx) -> ...
     return switch_mobile_off(ctx)
 
 
-def get_mobile_status(ctx: huaweisms.api.common.ApiCtx):
+def get_mobile_status(ctx):
+    # type: (huaweisms.api.common.ApiCtx) -> ...
     url = "{}/dialup/mobile-dataswitch".format(ctx.api_base_url)
     result = huaweisms.api.common.get_from_url(url, ctx)
     if result and result.get('type') == 'response':
@@ -29,7 +32,8 @@ def get_mobile_status(ctx: huaweisms.api.common.ApiCtx):
     return 'UNKNOWN'
 
 
-def switch_mobile_off(ctx: huaweisms.api.common.ApiCtx):
+def switch_mobile_off(ctx):
+    # type: (huaweisms.api.common.ApiCtx) -> ...
     data = XML_TEMPLATE.format(enable=0)
     headers = {
         '__RequestVerificationToken': ctx.token,
@@ -38,7 +42,8 @@ def switch_mobile_off(ctx: huaweisms.api.common.ApiCtx):
     return huaweisms.api.common.post_to_url(url, data, ctx, additional_headers=headers)
 
 
-def switch_mobile_on(ctx: huaweisms.api.common.ApiCtx):
+def switch_mobile_on(ctx):
+    # type: (huaweisms.api.common.ApiCtx) -> ...
     data = XML_TEMPLATE.format(enable=1)
     headers = {
         '__RequestVerificationToken': ctx.token,
