@@ -1,9 +1,21 @@
 from datetime import datetime
 
+import six
 from huaweisms.api.common import post_to_url, ApiCtx, get_from_url
 
 
-def get_sms(ctx: ApiCtx, box_type: int = 1, page: int = 1, qty: int = 1):
+def get_sms(ctx, box_type=1, page=1, qty=1, unread_preferred=True):
+    """
+     Gets available SMS from the router.
+
+    :param ctx: ApiCtx object.
+    :param box_type: 1 == inbox, 2 == outbox. integer.
+    :param page: page number during pagination (used with qty). integer.
+    :param qty: maximum number of items per page. integer.
+    :param unread_preferred: if True, unread SMS'es are listed first, otherwise
+        they are listed by date in descending order. boolean.
+    :return: a collection of sms records.
+    """
     xml_data = """
         <request>
             <PageIndex>{}</PageIndex>
@@ -11,9 +23,14 @@ def get_sms(ctx: ApiCtx, box_type: int = 1, page: int = 1, qty: int = 1):
             <BoxType>{}</BoxType>
             <SortType>0</SortType>
             <Ascending>0</Ascending>
-            <UnreadPreferred>1</UnreadPreferred>
+            <UnreadPreferred>{}</UnreadPreferred>
         </request>
-    """.format(page, qty, box_type)
+    """.format(
+        page,
+        qty,
+        box_type,
+        1 if unread_preferred else 0
+    )
 
     headers = {
         '__RequestVerificationToken': ctx.token,
@@ -30,11 +47,12 @@ def get_sms(ctx: ApiCtx, box_type: int = 1, page: int = 1, qty: int = 1):
     return r
 
 
-def send_sms(ctx: ApiCtx, dest, msg: str):
+def send_sms(ctx, dest, msg):
+    # type: (ApiCtx, ..., str) -> ...
 
     now = datetime.now()
     now_str = now.strftime("%Y-%m-%d %H:%M:%S")
-    dest = [dest] if isinstance(dest, str) else dest
+    dest = [dest] if isinstance(dest, six.string_types) else dest
 
     phones_content = '\n'.join('<Phone>{}</Phone>'.format(phone) for phone in dest)
     xml_data = """
@@ -60,7 +78,8 @@ def send_sms(ctx: ApiCtx, dest, msg: str):
     return r
 
 
-def delete_sms(ctx: ApiCtx, index: int):
+def delete_sms(ctx, index):
+    # type: (ApiCtx, int) -> ...
 
     xml_data = """
         <?xml version:"1.0" encoding="UTF-8"?>
@@ -78,6 +97,25 @@ def delete_sms(ctx: ApiCtx, index: int):
     return r
 
 
-def sms_count(ctx: ApiCtx):
+def sms_count(ctx):
+    # type: (ApiCtx) -> ...
     url = "{}/sms/sms-count".format(ctx.api_base_url)
     return get_from_url(url, ctx)
+
+
+def sms_set_read(ctx, index):
+    # type: (ApiCtx) -> ...
+
+    xml_data = """
+        <?xml version:"1.0" encoding="UTF-8"?>
+        <request>
+            <Index>{}</Index>
+        </request>
+    """.format(index)
+
+    headers = {
+        '__RequestVerificationToken': ctx.token,
+        'X-Requested-With': 'XMLHttpRequest'
+    }
+    url = "{}/sms/set-read".format(ctx.api_base_url)
+    return post_to_url(url, xml_data, ctx, headers)
