@@ -1,17 +1,20 @@
 from huaweisms.api.common import post_to_url, ApiCtx, get_from_url
 
 
-def status(ctx: ApiCtx):
+def status(ctx):
+    # type: (ApiCtx) -> ...
     url = "{}/ussd/status".format(ctx.api_base_url)
     return get_from_url(url, ctx)
 
 
-def get(ctx: ApiCtx):
+def get(ctx):
+    # type: (ApiCtx) -> ...
     url = "{}/ussd/get".format(ctx.api_base_url)
     return get_from_url(url, ctx)
 
 
-def send(ctx: ApiCtx, msg: str):
+def send(ctx, msg):
+    # type: (ApiCtx, str) -> ...
     xml_data = """
         <?xml version="1.0" encoding="UTF-8"?>
         <request>
