@@ -1,20 +1,24 @@
+import six
 from typing import Union
 from xml.dom import minidom
 from xml.dom.minidom import Element, Document
 
 
-def get_element_text(elem: Element) -> str:
+def get_element_text(elem):
+    # type: (Element) -> str
     return " ".join(t.nodeValue for t in elem.childNodes if t.nodeType == t.TEXT_NODE)
 
 
-def get_child_text(elem: Element, node_name: str) -> Union[str, None]:
+def get_child_text(elem, node_name):
+    # type: (Element, str) -> Union[str, None]
     children = elem.getElementsByTagName(node_name)
     if children:
         return get_element_text(children[0])
     return None
 
 
-def elements_dictionary(elem: Element) -> dict:
+def elements_dictionary(elem):
+    # type: (Element) -> dict
     ret = {}
     for node in elem.childNodes:
         if node.nodeType == node.ELEMENT_NODE:
@@ -28,7 +32,8 @@ def elements_dictionary(elem: Element) -> dict:
     return ret
 
 
-def get_dictionary_from_children(elem: Element):
+def get_dictionary_from_children(elem):
+    # type: (Element) -> ...
 
     ret = elements_dictionary(elem)
 
@@ -39,6 +44,9 @@ def get_dictionary_from_children(elem: Element):
                 ret[n] = get_dictionary_from_children(node)
             elif isinstance(ret[n], list):
                 ret[n].append(get_dictionary_from_children(node))
+            elif isinstance(ret[n], dict):
+                previous_val = ret[n]
+                ret[n] = [previous_val, get_dictionary_from_children(node)]
             else:
                 ret[n] = get_dictionary_from_children(node)
 
@@ -47,11 +55,14 @@ def get_dictionary_from_children(elem: Element):
     return ret
 
 
-def parse_xml_string(xml_string: str) -> Document:
-    return minidom.parseString(xml_string)
+def parse_xml_string(xml_string):
+    # type: (str) -> Document
+    parseable_xml_string = six.ensure_str(xml_string)
+    return minidom.parseString(parseable_xml_string)
 
 
-def dict_to_xml(data: dict) -> str:
+def dict_to_xml(data):
+    # type: (dict) -> str
     if not data:
         return ''
 
